/*
 * @(#) RFIDTag.java
 * 
 * RFID Tag Reader API
 * COMP150-TUI: Tangible User Interfaces
 * Tufts University, Department of Computer Science
 */
package rfid;



/**
 * Represents a single RFID tag.  Encapsulates a 64-bit RFID number,
 * an 8-bit DSFID number (an int between 0-255), and up to 1024 bytes
 * of read/write data.
 *
 * @author Team Evil Refrigerator
 * @version $Revision$, $Date$
 */
public class RFIDTag implements Comparable {

   public static final int DATA_BUFFER_SIZE = 1024;

   /** 64-bit RFID number for a tag */
   protected long rfid;

   /** 8-bit read/write DSFID code (useful as alternate tag ID) */
   protected int dsfid;

   /** Tags can store up to 1024 bytes of extra data */
   protected String data;
   
   /** The physical type of transpoder */ 
   protected int type;
   
   /** Reference to the RFIDReader */
   protected RFIDReader reader;

/**
 * Construct a tag with an RFID number
 */
   protected RFIDTag(RFIDReader reader, long rfid) {
      this.reader = reader;
      this.rfid = rfid;
      this.dsfid = 0;
      this.data = "";
   }

   public long getRFID() {
      return this.rfid;
   }

   public int getDSFID() {
      return this.dsfid;
   }

/**
 * Be sure to give this function an integer between 0-255
 */
   public void setDSFID(int dsfid) {
      this.dsfid = (0x000000FF & dsfid);
   }

/**
 * Sets a physical tag's DSFID number
 */
   public void writeDSFIDToTag() throws RFIDException {
       reader.writeDSFID(this);
   }

/**
 * Reads data from physical tag
 */
   public String readDataFromTag() throws RFIDException {
       reader.readData(this);
       return this.data;
   }

/**
 * Writes data to a physical tag.  Use setData() to set the data
 * prior to calling this method. 
 */
   public void writeDataToTag() throws RFIDException {
       reader.writeData(this);
   }
   
/**
 * Returns in-memory tag data.  Does not read from physical tag.
 */
   public String getData() {
       return this.data;
   }

/**
 * Sets in-memory tag data. Does not write to physical tag.
 */
   public void setData(String data) {
       this.data = data;
   }
   
   public int compareTo(Object other) {
       RFIDTag t = (RFIDTag)other;
       if(this.rfid - t.rfid == 0)
           return 0;
       else if(this.rfid - t.rfid > 0)
           return 1;
       else 
           return -1;
   }
   
   public String toString() { 
       return ("RFIDTag 0x" + Long.toHexString(rfid) + " " +
               "(DSFID int: " + dsfid + ")");
   }
}
