/*
 * @(#) TestApplication.java
 */
package rfid;


import javax.comm.*;
import java.util.Enumeration;

/**
 * Runs a series of diagnostic tests to make sure the OBID reader is
 * installed correctly. 
 */
public class TestApplication implements RFIDListener {

   public TestApplication() { }
    
   /**
     * Invoked when an RFID tag first becomes visible to the reader.
     */
   public void tagAdded(RFIDTag tag) {
      System.out.println("Tag Added: " + tag);
   }
   
   /**
    * Invoked when a visible tag is removed from the reader.
    */
   public void tagRemoved(RFIDTag tag) {
      System.out.println("Tag Removed: " + tag);
   }
   
   public static void main(String args[]) throws Exception {
      
      
      //-------------------------------------------------
      // Test 1:  List serial ports
      //-------------------------------------------------
      System.out.println("TEST 1: Enumerate Serial Ports...");
      java.util.List ports = new java.util.ArrayList();
      Enumeration enum = CommPortIdentifier.getPortIdentifiers();
      CommPortIdentifier portID;
      
      while (enum.hasMoreElements()) {
         portID = (CommPortIdentifier)enum.nextElement();
         
         if (portID.getPortType() == CommPortIdentifier.PORT_SERIAL)
         {
            System.out.println("   " + portID.getName());
            ports.add(portID.getName());
         }
      }
      
      if (ports.size() > 0) {
         System.out.println("OK");
      } else {
         System.out.println("FAILED! No Serial Ports Detected");
      }
      System.out.println();
      System.out.println();

      
      //-------------------------------------------------
      // Test 2:  Scan ports for reader
      //-------------------------------------------------
      System.out.println("TEST 2: Scan Ports for Reader...");
      String port;
      RFIDReader reader = null;

      for (int i=0; i<ports.size(); i++) {
         port = (String)ports.get(i);
         System.out.print("   Scanning " + port + "... ");
         try {
            reader = new RFIDReader(port);
            reader.hello();
            System.out.println(" reader found.");
            break;
         }
         catch (RFIDException rfidx) {
            System.out.println(" no reader found.");
	    if (reader != null) reader.stopScanner();
            reader = null;
         }
      }

      if (reader != null) {
         System.out.println("OBID Reader found on " + reader.port);
      } else {
         System.out.println("Unable to find OBID reader.");
      }
      System.out.println();
      System.out.println();

      
      //-------------------------------------------------
      // Test 3: Run in scan mode
      //-------------------------------------------------
      if (reader != null) { 
         System.out.println("TEST 3: Scan mode...");
         System.out.println("---Add and remove tags from reader");
         reader.addRFIDListener(new TestApplication());
      } else {
         System.exit(0);
      }
   }
}
